@@ -10,6 +10,6 @@ from .base import TrainingCallback, PredictionCallback, CallbackException
 from .early_stopping import EarlyStopping
 from .logging import EpochProgressLogger, BatchProgressLogger, \
     PredictionProgressLogger
-from .parallel import SynchronizationCallback
+from .parallel import SynchronizationCallback, ModelSharingCallback
 from .saving import ModelSaverCallback
 from .schedule import ParameterScheduler
