@@ -74,7 +74,7 @@ class BatchProgressLogger(TrainingCallback):
         self.progress = ProgressBar(num_iterations, self.file)
         self.progress.start()
 
-    def after_batch(self):
+    def after_batch(self, train_loss):
         self.progress.step()
 
     def after_epoch(self, metrics):
@@ -110,7 +110,7 @@ class PredictionProgressLogger(PredictionCallback):
         self.progress = ProgressBar(num_iterations, self.file)
         self.progress.start()
 
-    def after_batch(self):
+    def after_batch(self, *args):
         self.progress.step()
 
     def after_predictions(self):
