@@ -51,7 +51,7 @@ class ParameterScheduler(TrainingCallback):
     def before_epoch(self, current, num_iterations):
         self.epoch = current
 
-    def after_batch(self):
+    def after_batch(self, train_loss):
         self.iterations += 1
         self._update(True)
 
