@@ -6,7 +6,5 @@
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
 #
 
-from .dataset import Dataset
-from .infinite_dataset import InfiniteDataset
-from .infinite_loader import InfiniteDataLoader
 from .noise import NoiseDataset
+import bxtorch.nn.data.extensions
