@@ -6,13 +6,13 @@
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
 #  
 
-from .infinite_dataset import InfiniteDataset
+from torch.utils.data import IterableDataset
 import bxtorch.nn.functional as X
 
-class NoiseDataset(InfiniteDataset):
+class NoiseDataset(IterableDataset):
     """
     Infinite dataset for generating noise from a given probability distribution.
-    Should be used with Generative Adversarial Networks.
+    Can e.g. be used with Generative Adversarial Networks.
     """
 
     # MARK: Initialization
@@ -27,9 +27,19 @@ class NoiseDataset(InfiniteDataset):
         - dimension: int
             The dimension of the noise to generate.
         """
-        super().__init__(self._generator_func(noise_type, dimension))
+        super().__init__()
 
-    # MARK: Generator
+        self.noise_type = noise_type
+        self.dimension = dimension
+
+    # MARK: Special Methods
+    def __iter__(self):
+        # We do not need to consider single- or multi-process data loading since
+        # the noise is randomly sampled anyway
+        return self._generator_func(self.noise_type, self.dimension)
+
+    # MARK: Private Methods
     def _generator_func(self, noise_type, dimension):
         while True:
             yield X.generate_noise([dimension], noise_type)
+            
\ No newline at end of file
