@@ -1,5 +1,5 @@
 #
-#  bese.py
+#  base.py
 #  bxtorch
 #
 #  Created by Oliver Borchert on 09/05/19.
@@ -192,7 +192,7 @@ class BaseEngine(TrainingCallback, PredictionCallback, ABC):
                     loss = self.train_batch(item, **kwargs)
                     train_losses.append(loss)
                     self._exec_callbacks(
-                        train_callbacks, 'after_batch'
+                        train_callbacks, 'after_batch', loss
                     )
             else:
                 # 2.2.2) Dataset
@@ -202,13 +202,13 @@ class BaseEngine(TrainingCallback, PredictionCallback, ABC):
                     train_batch_weights.append(len(item))
                     train_losses.append(loss)
                     self._exec_callbacks(
-                        train_callbacks, 'after_batch'
+                        train_callbacks, 'after_batch', loss
                     )
 
             # 2.3) Validate
             batch_metrics = Evaluation(
                 self.collate_train_losses(train_losses),
-                train_batch_weights
+                train_batch_weights 
             )
 
             if val_data is not None:
@@ -415,10 +415,7 @@ class BaseEngine(TrainingCallback, PredictionCallback, ABC):
 
         # 3) Make sure that the model is not data parallel, we don't need this
         #    for predicting
-        if isinstance(self.model, nn.DataParallel):
-            model = self.model.module.eval()
-        else:
-            model = self.model.eval()
+        model = self.prediction_model.eval()
 
         # 4) Now perform predictions
         if (isinstance(gpu, list) and len(gpu) > 1) or gpu == False: 
@@ -439,17 +436,22 @@ class BaseEngine(TrainingCallback, PredictionCallback, ABC):
                 gpu=gpu, model=model
             )
 
+            iterator = iter(loader)
             predictions = vectorizer.process(
-                loader, model, self.process_prediction
+                (next(iterator) for _ in range(num_iterations)),
+                model, self.process_prediction
             )
-        else: 
+        else:
             # sequential computation
             device = gpu_device(gpu[0] if isinstance(gpu, list) else gpu)
             model = model.to(device)
 
             predictions = []
 
-            for x in loader:
+            iterator = iter(loader)
+            for _ in range(num_iterations):
+                x = next(iterator)
+
                 out = _prediction_worker_func(
                     x, model, self.process_prediction, device
                 )
@@ -606,6 +608,22 @@ class BaseEngine(TrainingCallback, PredictionCallback, ABC):
         """
         return {'train_loss': losses}
 
+    @property
+    def prediction_model(self):
+        """
+        Defines the model used for prediction. This is useful, e.g. in the
+        setting of a GAN where only the generator is used to make predictions.
+
+        Returns:
+        --------
+        - torch.nn.Module
+            The model to use for predictions.
+        """
+        if isinstance(self.model, nn.DataParallel):
+            return self.model.module
+        else:
+            return self.model
+
     # MARK: Private Methods
     def _setup_device(self, gpu):
         if isinstance(gpu, list) and len(gpu) > 1:
