@@ -6,4 +6,5 @@
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
 #
 
-from .rnn import StackedLSTM
+from .loss import BCELoss
+from .lstm import StackedLSTM, StackedLSTMCell
